==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/TCL/tkvfaq.tcl <==
# tkvfaq.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvfaq
catch {destroy $w}
toplevel $w
wm title $w "tkVoice FAQ"
wm iconname $w "tkVoice FAQ"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicepaths}
image create photo tkvoicepaths -file [file join $tkvoicedir/image/tkvoicefaq.gif]

label $w.gif.tkvoicepaths -image tkvoicepaths -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicepaths -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

#########################

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.cancel -side left -expand 1

text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" -setgrid 1 \
	     -height 30 -state normal
scrollbar $w.scroll -command "$w.text yview"
pack $w.scroll -side right -fill y
pack $w.text -expand yes -fill both
$w.text insert 0.0 \
{          _-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_
 
            This is the FAQ file for tkvoice 1.2a
 
                          Peter Bruley
                     pbruley@highstream.net
 
          -_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-


1.   Q: Won't install Won't run
        $ tkvoice
        /usr/local/bin/tkvoice: exec: wish: not found

     A: install tcl/tk it is available from:
                         http://www.scriptics.com/software/tcltk/

     Q: Modem won't answer calls (voice or fax)

     A: install mgetty/vgetty available from:
                         http://alpha.greenie.net/mgetty/

     Q: Can't view FAX's

     A: install netpbm tools available from:
                         http://sourceforge.net/projects/netpbm/

2.   Q: Won't record anything

     A: make sure you have a microphone attached to your sound card
        use a mixer panel to turn the microphone on and adjust the settings.

        Maybe you will need to re-compile the wavplay tools:
                        cd TKVoice_install_dir
                        cd wavplay-1.x
                        make clean
                        make no_x
                        as root: chmod +s wavplay wavrec

3.   Q: Complains about voice-spool directory permissions or won't delete
	messages:

     A: If you are running other than root user make sure you have read/write
        permissions for the voice-spool directory.
        for voice-spool directory.

4.   Q: Won't run after relocating to new directory or after installing new
	version:

        Error in startup script: couldn't open
        "/usr/local/tkvoice-1.2/image/tkvoice.gif":
        no such file or directory while executing
        "image create photo tkvoice -file [file join
        $tkvoicedir/image/tkvoice.gif]"
        (file "./tkvoice" line 687)

     A: Delete the contents of the hidden ".tkvoice" directory in your home
	directory:
        cd ~
        cd .tkvoice
        rm *
        cd /usr/local/tkvoice-1.x
        ./tkvoice

5.   Q: Won't Play anything

     A: Do other programs play sound through your sound card?
        If not then get sound working properly.

        If so then try recompiling the wavplay tools (see 2 above)
        or try a "custom" play back tool (can set this under options)
        This is the command, executed when playing via /dev/audio

        ie/ Try "playwave -r 7200" as custom command
        "playwave" comes with "SDL_mixer"
        The latest version of this library is available from:
        http://www.devolution.com/~slouken/SDL/projects/SDL_mixer/

6.   Q: Greeting / Messages are choppy or won't play.

     A: You are using the wrong type of compression method for your modem.

        -Greeting compression method can be changed in TKVOICE (modem options).          Then re-run the "convert WAV" command to re-install greeting using
         new compression method. (try "pvftormd -L" to see legal combinations)

        -Message compression (messages that are received by vgetty) can only
         be changed in the /usr/local/etc/mgetty+sendfax/voice.conf.
         Look for "rec_compression"

        -have a look at the messages that vgetty generates when a call is
	 received you will gain all sorts of debugging clues as to what is
         happening.
         (you may have to edit /usr/local/etc/mgetty+sendfax/voice.conf
	  and change your debug level: "voice_log_level" to 4 or 5)
         Then:
                cd /var/log (or /var/adm)
                tail -f vgetty.modem (or vgetty.ttyS4 etc.)

        NOTE/ Every modem uses a different type of chipset-compression method
              and sample speed.

        I have the following two modems and need to configure them as this:

        Modem Make: Aopen Model: FM56-ITU/2 (ISA bus modem)
                    Modem Type:         Rockwell
                    Compression:        4
                    Sample Speed:       7200

        Modem Make: 3COM Model: 3cp2976-oem-50 (PCI bus modem)
                    Modem Type:         US_Robotics
                    Compression:        1
                    Sample Speed:       8000


7.   Q: Caller ID does not work I always get "NOT AVAILABLE".

     A: Requirements to get CID working:
        -Need Caller ID support from your telephone service (telephone company).        -Need to have a modem that supports CallerID.
        -Need to initialize the modem so it will report CID (modem init string).
        I have two computers each with a different modem here are the lines
        I use to enable CID:

        Computer #1:
        Modem Make: Aopen Model: FM56-ITU/2 (ISA bus modem under /dev/ttyS3)
        -You would need to edit /usr/local/etc/mgetty+sendfax/mgetty.config
         and add the following options lines:
        # ----- port specific section -----
        port ttyS3
        debug 3
        init-chat "" \d\d\d+++\d\d\dAT&FE1V1&D2&C1&K3S95=47S0=0-SDR=5#CID=1 OK
        # -----

        Computer #2:
        Modem Make: 3COM Model: 3cp2976-oem-50 (PCI bus modem under /dev/ttyS4)         -You would need to edit /usr/local/etc/mgetty+sendfax/mgetty.config
         and add the following options lines:
        # ----- port specific section -----
        # USR Courier/Sportster 56k
        # 3com/USRobotics chipset PCI bus model: 3com 3cp2976-oem-50
	# modem is a symbolice link to ttyS4
        port modem
        debug 3
        init-chat "" \d\d\d+++\d\d\dAT&FE1V1&D2&C1S0=0S41=1#CID=1 OK
        # -----
 
        NOTE/ if you are using a link to your ttySx device ie /dev/modem instead              of /dev/ttyS4.
              You need to be consistent throughout all your config files:
                /etc/inittab
                /usr/local/etc/mgetty+sendfax/mgetty.config
                /usr/local/etc/mgetty+sendfax/voice.conf
 
              To check if you are using a link:
		This is a link:
                cd /dev
                ls -l modem
                lrwxrwxrwx    1 root     root    5 Nov 24 23:06 modem -> ttyS4

		This is NOT:
                cd /dev
                ls -l ttyS4
                crw-rw-r--    1 root     tty     4,  68 Jan  7 16:03     ttyS4

End of FAQ.}
$w.text configure -state disabled

==> tkvoice-1.3.tar.gz: tkvoice-1.3/TCL/tkvfaq.tcl <==
# tkvfaq.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvfaq
catch {destroy $w}
toplevel $w
wm title $w "tkVoice FAQ"
wm iconname $w "tkVoice FAQ"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

set bgcolor "#eeeeee"

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicepaths}
image create photo tkvoicepaths -file [file join $tkvoicedir/image/tkvoicefaq.gif]

label $w.gif.tkvoicepaths -image tkvoicepaths -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicepaths -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

#########################

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.cancel -side left -expand 1

text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" -setgrid 1 \
	     -height 30 -state normal -background $bgcolor
scrollbar $w.scroll -command "$w.text yview"
pack $w.scroll -side right -fill y
pack $w.text -expand yes -fill both
$w.text insert 0.0 \
{          _-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_
 
            This is the FAQ file for tkvoice 1.3
 
                          Peter Bruley
                     pbruley@highstream.net
 
          -_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-


1.   Q: Won't install Won't run
        $ tkvoice
        /usr/local/bin/tkvoice: exec: wish: not found

     A: Install tcl/tk it is available from:
        http://www.scriptics.com/software/tcltk/

     Q: Modem won't answer calls (voice or fax)

     A: Install mgetty/vgetty available from:
        http://alpha.greenie.net/mgetty/

     Q: Can't view FAX's

     A: Install netpbm tools available from:
        http://sourceforge.net/projects/netpbm/

2.   Q: Won't record anything

     A: make sure you have a microphone attached to your sound card
        use a mixer panel to turn the microphone on and adjust the settings.

        Maybe you will need to re-compile the wavplay tools:
                        cd TKVoice_install_dir
                        cd wavplay-1.x
                        make clean
                        make no_x
                        as root: chmod +s wavplay wavrec

	wavplay-wavrec won't compile then try "sox" under setup-audio.

	If you need to get a copy of "sox" it is available from:
        http://sox.sourceforge.net/

3.   Q: Complains about voice-spool directory permissions or won't delete
	messages:

     A: If you are running other than root user make sure you have read/write
        permissions for the voice-spool directory.

4.   Q: Won't run after relocating to new directory or after installing new
	version:

        Error in startup script: couldn't open
        "/usr/local/tkvoice-1.2/image/tkvoice.gif":
        no such file or directory while executing
        "image create photo tkvoice -file [file join
        $tkvoicedir/image/tkvoice.gif]"
        (file "./tkvoice" line 687)

     A: Delete the contents of the hidden ".tkvoice" directory in your home
	directory:
        cd ~
        cd .tkvoice
        rm *
        cd /usr/local/tkvoice-1.x
        ./tkvoice

5.   Q: Won't Play anything

     A: Do other programs play sound through your sound card?
        If not then get sound working properly.

        If so then try recompiling the wavplay tools (see 2 above)
        or try a "custom" play back tool (can set this under options)
        This is the command, executed when playing via /dev/audio

        ie/ Try "playwave -r 7200" as custom command
        "playwave" comes with "SDL_mixer"
        The latest version of this library is available from:
        http://www.devolution.com/~slouken/SDL/projects/SDL_mixer/

6.   Q: Greeting / Messages are choppy or won't play.

     A: You are using the wrong type of compression method for your modem.

        -Greeting compression method can be changed in TKVOICE (Options>Voice>
         Setup Modem).Then re-run the "convert WAV" command to re-install 
         greeting using new compression method.
         (From a terminal seesion try: "pvftormd -L" to see legal combinations)

        -Message compression (messages that are received by vgetty) can only
         be changed in the /usr/local/etc/mgetty+sendfax/voice.conf.
         Look for "rec_compression"

        -have a look at the messages that vgetty generates when a call is
	 received you will gain all sorts of debugging clues as to what is
         happening.
         (you may have to edit /usr/local/etc/mgetty+sendfax/voice.conf
	  and change your debug level: "voice_log_level" to 4 or 5)
         Then:
                cd /var/log (or /var/adm)
                tail -f vgetty.modem (or vgetty.ttyS4 etc.)

        NOTE/ Every modem uses a different type of chipset-compression method
              and sample speed.

        I have the following two modems and need to configure them as this:

        Modem Make: Aopen Model: FM56-ITU/2 (ISA bus modem)
                    Modem Type:         Rockwell
                    Compression:        4
                    Sample Speed:       7200

        Modem Make: 3COM Model: 3cp2976-oem-50 (PCI bus modem)
                    Modem Type:         US_Robotics
                    Compression:        1
                    Sample Speed:       8000


7.   Q: Caller ID does not work I always get "NOT AVAILABLE".

     A: Requirements to get CID working:
        -Need Caller ID support from your telephone service (telephone company).        -Need to have a modem that supports CallerID.
        -Need to initialize the modem so it will report CID (modem init string).
        I have two computers each with a different modem here are the lines
        I use to enable CID:

        Computer #1:
        Modem Make: Aopen Model: FM56-ITU/2 (ISA bus modem under /dev/ttyS3)
        -You would need to edit /usr/local/etc/mgetty+sendfax/mgetty.config
         and add the following options lines:
        # ----- port specific section -----
        port ttyS3
        debug 3
        init-chat "" \d\d\d+++\d\d\dAT&FE1V1&D2&C1&K3S95=47S0=0-SDR=5#CID=1 OK
        # -----

        Computer #2:
        Modem Make: 3COM Model: 3cp2976-oem-50 (PCI bus modem under /dev/ttyS4)         -You would need to edit /usr/local/etc/mgetty+sendfax/mgetty.config
         and add the following options lines:
        # ----- port specific section -----
        # USR Courier/Sportster 56k
        # 3com/USRobotics chipset PCI bus model: 3com 3cp2976-oem-50
	# modem is a symbolice link to ttyS4
        port modem
        debug 3
        init-chat "" \d\d\d+++\d\d\dAT&FE1V1&D2&C1S0=0S41=1#CID=1 OK
        # -----
 
        NOTE/ if you are using a link to your ttySx device ie /dev/modem instead              of /dev/ttyS4.
              You need to be consistent throughout all your config files:
                /etc/inittab
                /usr/local/etc/mgetty+sendfax/mgetty.config
                /usr/local/etc/mgetty+sendfax/voice.conf
 
              To check if you are using a link:
		This is a link:
                cd /dev
                ls -l modem
                lrwxrwxrwx    1 root     root    5 Nov 24 23:06 modem -> ttyS4

		This is NOT:
                cd /dev
                ls -l ttyS4
                crw-rw-r--    1 root     tty     4,  68 Jan  7 16:03     ttyS4

8.   Q: I get an error message when "converting WAV to RMD".

     A: This happens when a unsupported modem option is selected.
        Try choosing a different Samples/sec or compression method.
        From a serial communication package (such as seyon) try to determine
        the compression methods your modem supports. You will of coarse need
        to know the AT Commands for your modem. Most modems will respond to:
        "AT+FCLASS=8" and then issue "AT+VSM=?" or "AT+VSM?".
	
	Also the voice modem you have may not be supported by vgetty. 
	Check the vgetty Modem Database:
	http://alpha.greenie.net/vgetty/modem_database.html
	OR if you are a hacker at heart look in the sources: 
	/path/mgetty-1.1.xx/voice/libvoice/detect.c

End of FAQ.}
$w.text configure -state disabled
